from setuptools import setup

setup(
    name='causaldag',
    version='0.1a',
    description='Causal DAG manipulation and inference',
    url='http://github.com/storborg/funniest',
    author='Chandler Squires',
    author_email='chandlersquires18@gmail.com',
    packages=['causaldag'],
    zip_safe=False
)

